/*!
 * Copyright (c) 2024 ENEO Tecnología S.L.
 * This file is part of redBorder.
 * redBorder is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * redBorder is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 * You should have received a copy of the GNU Affero General Public License
 * along with redBorder. If not, see <http://www.gnu.org/licenses/>.
 */

$(document).on("click", ".type-object-trigger", function(event) {
  event.preventDefault();
  const typeObjectId = $(this).data("id");

  // Marcar el checkbox que corresponde al ID
  $('input[name="search[inventory_device_type_object][]"][value="' + typeObjectId + '"]').prop('checked', true);

  // Enviar el formulario
  $("#inventory-devices-search-form").submit();
});


$(document).on("click", "#inventory-devices-select-all", function(event) {
  $('input[name="selected_inventory_devices[]"]').each(function() {
    this.checked = event.target.checked;
    $(this).trigger('change');
  });
});

$(document).on("click", "#inventory-devices-dropdownMenuButton", function(event) {
  event.stopPropagation();
  $(this).closest('.dropdown').toggleClass('show-options');
});

$(document).ready(function() {
  var storedIds = JSON.parse(localStorage.getItem('selected_inventory_devices')) || [];
  storedIds.forEach(function(id) {
    $('input[name="selected_inventory_devices[]"][value="' + id + '"]').prop('checked', true);
  });
});

// Actualizar el localStorage cada vez que se selecciona o deselecciona un checkbox
$(document).on('change', 'input[name="selected_inventory_devices[]"]', function() {
  var selected = JSON.parse(localStorage.getItem('selected_inventory_devices')) || [];

  if (this.checked) {
    // Añadir el ID si no está ya en el array
    if (!selected.includes(parseInt(this.value, 10))) {
      selected.push(parseInt(this.value, 10));
    }
  } else {
    // Remover el ID si se deselecciona
    selected = selected.filter(function(id) {
      return id !== parseInt(this.value, 10);
    }.bind(this));
  }

  localStorage.setItem('selected_inventory_devices', JSON.stringify(selected));
});

$(document).on("click", "#delete-selected-inventory-devices", function(event) {
  var bulkDeleteForm = $('#bulk-delete-form-inventory-devices');
  var deleteInventoryDeviceIdsContainer = $('#bulk-delete-inventory-device-ids');
  var deletePageInput = $('#bulk-delete-page-inventory-devices');

  event.preventDefault();

  var selected = JSON.parse(localStorage.getItem('selected_inventory_devices')) || [];

  if (selected.length > 0) {
    if (confirm('Are you sure you want to delete the selected assets?')) {
      // Limpiar los valores antiguos
      deleteInventoryDeviceIdsContainer.empty();
      selected.forEach(function(id) {
        deleteInventoryDeviceIdsContainer.append('<input type="hidden" name="inventory_device_ids[]" value="' + id + '">');
      });

      deletePageInput.val(new URLSearchParams(window.location.search).get('page') || 1);
      localStorage.removeItem('selected_inventory_devices');
      bulkDeleteForm.submit();
    }
  } else {
    alert('Please select at least one asset.');
  }
});

$(document).on("click", ".dropdown-item[data-criticality]", function(event) {
  var bulkUpdateForm = $('#bulk-update-form-inventory-devices');
  var criticalityInput = $('#bulk-update-criticality-inventory-devices');
  var updateInventoryDeviceIdsContainer = $('#bulk-update-inventory-devices-ids');
  var updatePageInput = $('#bulk-update-page-inventory-devices');

  event.preventDefault();

  var criticality = $(this).data('criticality');
  var selected = JSON.parse(localStorage.getItem('selected_inventory_devices')) || [];

  if (selected.length > 0) {
    criticalityInput.val(criticality);
    // Limpiar los valores antiguos
    updateInventoryDeviceIdsContainer.empty();
    selected.forEach(function(id) {
      updateInventoryDeviceIdsContainer.append('<input type="hidden" name="inventory_device_ids[]" value="' + id + '">');
    });

    updatePageInput.val(new URLSearchParams(window.location.search).get('page') || 1);
    localStorage.removeItem('selected_inventory_devices');
    bulkUpdateForm.submit();
  } else {
    alert('Please select at least one asset.');
  }
});

// Event delegation for removing filters
$(document).on('click', '.remove-inventory-devices-filter', function() {
  const filterType = $(this).data('filter');
  const filterValue = $(this).data('value');

  const filterMappings = {
    'name': 'input[name="name"]',
    'criticality': 'input[name="search[criticality][]"]',
    'domain': 'input[name="search[domain][]"]',
    'sources': 'input[name="search[sources][]"]',
    'inventory_device_type_object': 'input[name="search[inventory_device_type_object][]"]',
    'minimum_criticality': 'select[name="search[minimum_criticality]"]',
    'is_locked': 'select[name="search[is_locked]"]',
    'order_by': 'select[name="search[order_by]"]',
    'order_direction': 'select[name="search[order_direction]"]',
    'exclude': 'input[name="search[exclude]"]'
  };

  const formElement = $(filterMappings[filterType]);

  if (formElement.is('input[type="text"]')) {
    formElement.val('');
  } else if (formElement.is('input[type="checkbox"]')) {
    formElement.filter('[value="' + filterValue + '"]').prop('checked', false);
  } else if (formElement.is('select')) {
    formElement.val('');
  }

  //Remove the selected inventory devices from the localStorage
  localStorage.removeItem('selected_inventory_devices');

  // Submit the form to apply the changes
  $('#inventory-devices-search-form').submit();
});

$(document).on('click', 'a[href="/inventory_devices/reset_filters"]', function() {
  document.querySelectorAll(".inventory-devices-filter-container input[type=checkbox]").forEach(function(check) {
    check.checked = false;
  });
});
