#######################################################################
# Copyright (c) 2025 ENEO Tecnologia S.L.
# This file is part of redBorder.
# redBorder is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# redBorder is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
# You should have received a copy of the GNU Affero General Public License
# along with redBorder. If not, see <http://www.gnu.org/licenses/>.
#######################################################################

class UpdateSources < ActiveRecord::Migration[5.0]
  def up
    # Update source incident fields
    Incident.where(source: 'redBorder Intrusion').update_all(source: 'Intrusion')
    Incident.where(source: 'redBorder Vault').update_all(source: 'Vault')
    Incident.where(source: 'redBorder Traffic').update_all(source: 'Traffic')

    # Update source inventory device fields
    InventoryDevice.where("'redBorder Traffic' = ANY(sources)").find_each do |device|
      updated_sources = device.sources.map { |s| s == 'redBorder Traffic' ? 'Traffic' : s }
      device.update_columns(sources: updated_sources)
    end
    InventoryDevice.where("'redBorder User' = ANY(sources)").find_each do |device|
      updated_sources = device.sources.map { |s| s == 'redBorder User' ? 'User' : s }
      device.update_columns(sources: updated_sources)
    end
  end

  def down
    # Revert source incident fields
    Incident.where(source: 'Intrusion').update_all(source: 'redBorder Intrusion')
    Incident.where(source: 'Vault').update_all(source: 'redBorder Vault')
    Incident.where(source: 'Traffic').update_all(source: 'redBorder Traffic')
    
    # Revert source inventory device fields
    InventoryDevice.where("'Traffic' = ANY(sources)").find_each do |device|
      updated_sources = device.sources.map { |s| s == 'Traffic' ? 'redBorder Traffic' : s }
      device.update_columns(sources: updated_sources)
    end
    InventoryDevice.where("'User' = ANY(sources)").find_each do |device|
      updated_sources = device.sources.map { |s| s == 'User' ? 'redBorder User' : s }
      device.update_columns(sources: updated_sources)
    end
  end
end
