#######################################################################
# Copyright (c) 2014 ENEO Tecnologia S.L.
# This file is part of redBorder.
# redBorder is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# redBorder is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
# You should have received a copy of the GNU Affero General Public License
# along with redBorder. If not, see <http://www.gnu.org/licenses/>.
#######################################################################

module Redborder

  module Jobs

    class RuleUpdatedbJob < Struct.new(:user_id, :verbose)
      
      include Redborder::Jobs::JobHelper

      def perform
        enabled_sources = RuleSource.where(is_custom: false, enable: true).pluck(:id)
      
        RuleSource.where(id: enabled_sources).update_all(updating: true)
        content = ""
      
        snort2_sources = RuleSource.where(id: enabled_sources, snort_version: [nil, 'snort2'])
        snort3_sources = RuleSource.where(id: enabled_sources, snort_version: 'snort3')
      
        begin
          unless snort2_sources.empty?
            RuleSource.where(snort_version: 'snort3').update_all(enable: false)
            content += Redborder::RulesUpdate.start(true)
            RuleSource.where(snort_version: 'snort3').update_all(enable: true)
          end
      
          unless snort3_sources.empty?
            RuleSource.where(snort_version: [nil, 'snort2']).update_all(enable: false)
            content += Redborder::RulesUpdateSnort3.start(true)
            RuleSource.where(snort_version: [nil, 'snort2']).update_all(enable: true)
          end
        rescue StandardError => e
          logit "#{e}"
          content += "Error during rules update: #{e.message}\n"
        end
      
        hour, minute = Setting.rule_update_time.split(":").map(&:to_i)

        if Setting.rule_update_periodicity == "weekly"
          Delayed::Job.enqueue(Redborder::Jobs::RuleUpdatedbJob.new(user_id, true), priority: 10, run_at: 1.week.from_now.beginning_of_day + hour.hour + minute.minute)
        elsif Setting.rule_update_periodicity == "daily"
          Delayed::Job.enqueue(Redborder::Jobs::RuleUpdatedbJob.new(user_id, true), priority: 10, run_at: 1.day.from_now.beginning_of_day + hour.hour + minute.minute)
        else
          Delayed::Job.enqueue(Redborder::Jobs::RuleUpdatedbJob.new(user_id, true), priority: 10, run_at: 1.hour.from_now)
        end
      rescue Exception => e
        logit "#{e}"
        content += "#{e}\n"
      ensure
        RuleSource.where(is_custom: false).update_all(enable: false, updating: false)
        RuleSource.where(id: enabled_sources).update_all(enable: true)
      
        sources_names = RuleSource.where(id: enabled_sources).map(&:clean_name).join(', ')
        StoredDelayedJob.create(user_id: user_id, job: "RuleUpdatedbJob", options: { humanize: sources_names }, content: content)
      end      

    end

  end

end
